Documentation
¶
Overview ¶
Package slicetype implements data types and utilities to describe Bigslice types: Slices, Frames, and Tasks all carry slicetype.Types.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Assignable ¶
Assignable reports whether column type in can be assigned to out.
Types ¶
type Type ¶
type Type interface {
// NumOut returns the number of columns.
NumOut() int
// Out returns the data type of the ith column.
Out(i int) reflect.Type
// Prefix returns the number of columns in the type
// which are considered the type's prefix. A type's
// prefix is the set of columns which are considered
// the type's key columns for operations like reduce.
Prefix() int
}
A Type is the type of a set of columns.
Notes ¶
Bugs ¶
prefixes are lost when slicing a type.
Click to show internal directories.
Click to hide internal directories.